@@ -13,9 +13,5 @@ class Converter(Element):
 	def handleCommand(self, cmd):
 		self.source.handleCommand(cmd)
 
-	def appendToStringWithSeparator(self, str, part):
-		if str == "":
-			str = part
-		else:
-			str = str + self.separator + part
-		return str
+	def appendToStringWithSeparator(self, text, part):
+		return f"{text}{self.separator or ' '}{part}" if text else part
