@@ -23,10 +23,11 @@ from enigma import iPlayableService, eTimer, eSize, eDVBDB, eServiceReference, e
 FOCUS_CONFIG, FOCUS_STREAMS = range(2)
 [PAGE_AUDIO, PAGE_SUBTITLES] = ["audio", "subtitles"]
 
-
 selectionpng = LoadPixmap(cached=True, path=resolveFilename(SCOPE_GUISKIN, "icons/audioselectionmark.png"))
 
-
+def isIPTV(service):
+	path = service and service.getPath()
+	return path and not path.startswith("/") and service.type in [0x1, 0x1001, 0x138A, 0x1389]
 class AudioSelection(ConfigListScreen, Screen):
 	def __init__(self, session, infobar=None, page=PAGE_AUDIO):
 		Screen.__init__(self, session)
@@ -84,6 +85,9 @@ class AudioSelection(ConfigListScreen, Screen):
 		self.focus = FOCUS_STREAMS
 		self.settings.menupage.addNotifier(self.fillList)
 
+	def saveAVDict(self):
+		eDVBDB.getInstance().saveIptvServicelist()
+
 	def fillList(self, arg=None):
 		streams = []
 		conflist = []
@@ -237,7 +241,6 @@ class AudioSelection(ConfigListScreen, Screen):
 						description = types[x[2]]
 					except:
 						description = _("unknown") + ": %s" % x[2]
-					number = str(int(number) + 1)
 
 				streams.append((x, "", number, description, language, selected, selectionpng if selected == "X" else None))
 				idx += 1
@@ -284,8 +287,13 @@ class AudioSelection(ConfigListScreen, Screen):
 	def changeAudio(self, audio):
 		track = int(audio)
 		if isinstance(track, int):
-			if self.session.nav.getCurrentService().audioTracks().getNumberOfTracks() > track:
+			service = self.session.nav.getCurrentService()
+			ref = self.session.nav.getCurrentlyPlayingServiceReference()
+			#ref = ref and eServiceReference(ref.toString())
+			if service.audioTracks().getNumberOfTracks() > track:
 				self.audioTracks.selectTrack(track)
+				if isIPTV(ref):
+					self.saveAVDict()
 
 	def keyLeft(self):
 		if self.focus == FOCUS_CONFIG:
@@ -387,6 +395,8 @@ class AudioSelection(ConfigListScreen, Screen):
 			if self.settings.menupage.getValue() == PAGE_AUDIO and cur[0] is not None:
 				self.changeAudio(cur[0])
 				self.__updatedInfo()
+			ref = self.session.nav.getCurrentlyPlayingServiceReference()
+			#ref = ref and eServiceReference(ref.toString())
 			if self.settings.menupage.getValue() == PAGE_SUBTITLES and cur[0] is not None:
 				if config.subtitles.show.value and self.infobar.selected_subtitle and self.infobar.selected_subtitle[:4] == cur[0][:4]:
 					self.infobar.enableSubtitle(None)
@@ -397,6 +407,8 @@ class AudioSelection(ConfigListScreen, Screen):
 					config.subtitles.show.value = True
 					self.infobar.enableSubtitle(cur[0][:5])
 					self.__updatedInfo()
+				if isIPTV(ref):
+					self.saveAVDict()
 			self.close(0)
 		elif self.focus == FOCUS_CONFIG:
 			self.keyRight()
@@ -453,7 +465,7 @@ class QuickSubtitlesConfigMenu(ConfigListScreen, Screen):
 		sub = self.infobar.selected_subtitle
 		if sub[0] == 0:  # dvb
 			menu = [
-				getConfigMenuItem("config.subtitles.dvb_subtitles_yellow"),
+				getConfigMenuItem("config.subtitles.dvb_subtitles_color"),
 				getConfigMenuItem("config.subtitles.dvb_subtitles_backtrans"),
 				getConfigMenuItem("config.subtitles.dvb_subtitles_original_position"),
 				(_("Center DVB subtitles"), self.center_dvb_subs),
